summaryrefslogtreecommitdiff
path: root/condvar.c
diff options
context:
space:
mode:
authorrpj <rpj>2000-09-02 04:02:20 +0000
committerrpj <rpj>2000-09-02 04:02:20 +0000
commit54286bb31e57ff4ae0f03810b7acc27031bcb034 (patch)
tree09ab610b97afa1f2d464f8dd2bf2ec64ab05b9ce /condvar.c
parent9250a2a259e1163c3c3e234366a1b8c65b64a89f (diff)
2000-09-02 Ross Johnson <rpj@special.ise.canberra.edu.au>
* rwlock.c (_rwlock_check*): Renamed to ptw32_rwlock_check*. * mutex.c (_mutex_check*): Renamed to ptw32_mutex_check*. * condvar.c (cond_timed*): Renamed to ptw32_cond_timed*. (_cond_check*): Renamed to ptw32_cond_check*.
Diffstat (limited to 'condvar.c')
-rw-r--r--condvar.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/condvar.c b/condvar.c
index 87e62d8..3c5999f 100644
--- a/condvar.c
+++ b/condvar.c
@@ -27,7 +27,7 @@
#include "implement.h"
static int
-_cond_check_need_init(pthread_cond_t *cond)
+ptw32_cond_check_need_init(pthread_cond_t *cond)
{
int result = 0;
@@ -490,7 +490,7 @@ pthread_cond_destroy (pthread_cond_t * cond)
else
{
/*
* See notes in _cond_check_need_init() above also.
*/
EnterCriticalSection(&ptw32_cond_test_init_lock);
@@ -585,7 +585,7 @@ cond_wait_cleanup(void * args)
}
static int
-cond_timedwait (pthread_cond_t * cond,
+ptw32_cond_timedwait (pthread_cond_t * cond,
pthread_mutex_t * mutex,
const struct timespec *abstime)
{
@@ -601,12 +601,12 @@ cond_timedwait (pthread_cond_t * cond,
/*
* We do a quick check to see if we need to do more work
* to initialise a static condition variable. We check
* again inside the guarded section of _cond_check_need_init()
* to avoid race conditions.
*/
if (*cond == (pthread_cond_t) PTW32_OBJECT_AUTO_INIT)
{
- result = _cond_check_need_init(cond);
+ result = ptw32_cond_check_need_init(cond);
}
if (result != 0 && result != EBUSY)
@@ -677,7 +677,7 @@ cond_timedwait (pthread_cond_t * cond,
*/
return (result);
-} /* cond_timedwait */
+} /* ptw32_cond_timedwait */
int
@@ -731,7 +731,7 @@ pthread_cond_wait (pthread_cond_t * cond,
*/
{
/* The NULL abstime arg means INFINITE waiting. */
- return(cond_timedwait(cond, mutex, NULL));
+ return(ptw32_cond_timedwait(cond, mutex, NULL));
} /* pthread_cond_wait */
@@ -792,7 +792,7 @@ pthread_cond_timedwait (pthread_cond_t * cond,
}
else
{
- result = cond_timedwait(cond, mutex, abstime);
+ result = ptw32_cond_timedwait(cond, mutex, abstime);
}
return(result);
@@ -490,7 +490,7 @@ pthread_cond_destroy (pthread_cond_t * cond)
{
/*
- * See notes in _cond_check_need_init() above also.
+ * See notes in ptw32_cond_check_need_init() above also.
*/
EnterCriticalSection(&ptw32_cond_test_init_lock);
@@ -601,12 +601,12 @@ cond_timedwait (pthread_cond_t * cond,
* We do a quick check to see if we need to do more work
* to initialise a static condition variable. We check
- * again inside the guarded section of _cond_check_need_init()
+ * again inside the guarded section of ptw32_cond_check_need_init()
* to avoid race conditions.
*/